/**
 * Copyright 2007-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.pool.impl;

import org.ow2.util.pool.annotation.Pool;
import org.ow2.util.pool.api.IPoolConfiguration;

/**
 * Helper class that extracts data from annotation and returns a {@link PoolConfiguration} object.
 * @author Florent BENOIT
 */
public final class PoolConfigurationHelper {

    /**
     * Utility class, no public constructor.
     */
    private PoolConfigurationHelper() {

    }

    /**
     * Allow to return a configuration for the pool by extracting data from the {@link Pool} annotation.
     * @param poolAnnotation the given Pool annotation to analyze
     * @return a PoolConfiguration instance
     */
    public static IPoolConfiguration getConfiguration(final Pool poolAnnotation) {
        // Create object
        PoolConfiguration poolConfiguration = new PoolConfiguration();

        // Analyze values of the annotation
        poolConfiguration.setMax(poolAnnotation.max());
        poolConfiguration.setMaxWaiters(poolAnnotation.maxWaiters());
        poolConfiguration.setTimeout(poolAnnotation.timeout());
        poolConfiguration.setMin(poolAnnotation.min());
        poolConfiguration.setSpare(poolAnnotation.spare());

        return poolConfiguration;
    }
}
